package MFVec3f;
use strict;
use warnings;

use rlib "./";

use MFValue;
use base qw(MFValue);

use SFVec3f;
our $SField = new SFVec3f;

1;
__END__
